# IssueBadge Developer Guide

**Transform your badge management with AI-powered automation**

Welcome to the IssueBadge Developer Guide! This comprehensive resource will help you integrate our powerful badge management API into your applications and leverage our cutting-edge MCP server for AI-powered badge automation.

## 🚀 Quick Start

### 1. Get Your API Key
1. Log into your IssueBadge dashboard
2. Navigate to **Settings > API Keys**
3. Generate a new API key
4. Copy and securely store your key

### 2. Test Your Integration
```bash
curl -X POST "https://app.issuebadge.com/api/v1/validate-key" \
  -H "Content-Type: application/json" \
  -d '{"api_key": "your_api_key_here"}'
```

### 3. Create Your First Badge
```bash
curl -X POST "https://app.issuebadge.com/api/v1/badge/create" \
  -H "Authorization: Bearer your_api_key" \
  -F "name=Developer Certification" \
  -F "description=Awarded to skilled developers" \
  -F "issuing_organization_name=Your Company" \
  -F "idempotency_key=dev_cert_$(date +%s)"
```

## 📚 Documentation Resources

### **Interactive API Documentation**
- **Live Documentation**: [Open API Docs](./api-documentation.html)
- **Swagger Specification**: [OpenAPI YAML](./api-swagger.yaml)
- **Postman Collection**: [Download Collection](./postman-collection.json)

### **Core API Endpoints**
- **Authentication**: `POST /api/v1/validate-key`
- **Badge Management**: `GET /api/v1/badge/getall` • `POST /api/v1/badge/create`
- **Badge Issuance**: `POST /api/v1/issue/create`

## 🤖 AI-Powered Badge Management with MCP Server

### **What is MCP?**
Model Context Protocol (MCP) is a new standard that allows AI assistants to securely connect to external systems. Our MCP server enables you to manage badges using natural language with AI assistants like Claude.

### **MCP Server Features**
- **Natural Language Interface**: "Create a badge for web development certification"
- **Automated Workflows**: "Issue badges to all students who completed the course"
- **Smart Validation**: "Check if this API key is valid"
- **Bulk Operations**: "Get all available badges and issue the JavaScript cert to John"

### **Quick MCP Setup**

#### 1. Install MCP Server
```bash
# Clone or download the MCP server
cd mcp-server
npm install
npm run build
```

#### 2. Configure Environment
```bash
cp .env.example .env
# Edit .env with your API credentials:
ISSUEBADGE_API_KEY=your_api_key_here
ISSUEBADGE_BASE_URL=https://app.issuebadge.com/api/v1
```

#### 3. Use with Claude Desktop
Add to your Claude Desktop configuration:
```json
{
  "mcpServers": {
    "issuebadge": {
      "command": "node",
      "args": ["/absolute/path/to/mcp-server/dist/index.js"],
      "env": {
        "ISSUEBADGE_API_KEY": "your_api_key_here",
        "ISSUEBADGE_BASE_URL": "https://app.issuebadge.com/api/v1"
      }
    }
  }
}
```

#### 4. Start Using AI Commands
Once configured, you can interact with IssueBadge using natural language in Claude:

```
"Create a badge called 'Python Mastery' for completion of our Python course"

"Issue the Web Development badge to sarah@example.com with completion date today"

"Show me all available badges in our system"

"Validate my API key to make sure it's working"
```

## 💡 Use Cases & Examples

### **Educational Institutions**
```javascript
// Automatically issue course completion badges
const students = await getCompletedStudents('web-dev-101');
for (const student of students) {
  await issueBadge({
    badge_id: 'web_dev_cert',
    name: student.name,
    email: student.email,
    metadata: {
      completion_date: new Date().toISOString(),
      final_grade: student.grade
    }
  });
}
```

### **Corporate Training**
```javascript
// Bulk certification for training programs
const trainees = await getTrainingCompletions('security-training');
await batchIssueBadges(trainees, 'security_cert', {
  training_date: '2024-01-15',
  trainer: 'Jane Smith',
  location: 'Remote'
});
```

### **Event Management**
```javascript
// Issue attendance badges after events
const attendees = await getEventAttendees('tech-conference-2024');
await issueBadges(attendees, 'conference_attendance', {
  event_name: 'Tech Conference 2024',
  event_date: '2024-03-15',
  location: 'San Francisco'
});
```

## 🔧 Integration Examples

### **React/Next.js Integration**
```javascript
// hooks/useBadgeAPI.js
import { useState, useEffect } from 'react';

export function useBadgeAPI() {
  const [badges, setBadges] = useState([]);
  const [loading, setLoading] = useState(false);

  const createBadge = async (badgeData) => {
    setLoading(true);
    try {
      const response = await fetch('/api/v1/badge/create', {
        method: 'POST',
        headers: {
          'Authorization': `Bearer ${process.env.ISSUEBADGE_API_KEY}`,
          'Content-Type': 'application/json'
        },
        body: JSON.stringify(badgeData)
      });
      return await response.json();
    } finally {
      setLoading(false);
    }
  };

  const getAllBadges = async () => {
    const response = await fetch('/api/v1/badge/getall', {
      headers: {
        'Authorization': `Bearer ${process.env.ISSUEBADGE_API_KEY}`
      }
    });
    const data = await response.json();
    setBadges(data.data);
    return data;
  };

  return { badges, createBadge, getAllBadges, loading };
}
```

### **Node.js Express Middleware**
```javascript
// middleware/badgeAuth.js
const axios = require('axios');

async function validateIssueBadgeKey(req, res, next) {
  try {
    const apiKey = req.headers['x-issuebadge-key'];
    const response = await axios.post('https://app.issuebadge.com/api/v1/validate-key', {
      api_key: apiKey
    });
    
    if (response.data.success) {
      req.issueBadgeAuth = response.data.data;
      next();
    } else {
      res.status(401).json({ error: 'Invalid IssueBadge API key' });
    }
  } catch (error) {
    res.status(500).json({ error: 'Badge API validation failed' });
  }
}

module.exports = { validateIssueBadgeKey };
```

### **Python Integration**
```python
# badge_manager.py
import requests
import os
from typing import Dict, List, Optional

class IssueBadgeClient:
    def __init__(self, api_key: str, base_url: str = None):
        self.api_key = api_key
        self.base_url = base_url or "https://app.issuebadge.com/api/v1"
        self.headers = {
            "Authorization": f"Bearer {api_key}",
            "Content-Type": "application/json"
        }
    
    def validate_key(self) -> Dict:
        """Validate the API key"""
        response = requests.post(
            f"{self.base_url}/validate-key",
            json={"api_key": self.api_key}
        )
        return response.json()
    
    def get_all_badges(self) -> List[Dict]:
        """Get all available badges"""
        response = requests.get(
            f"{self.base_url}/badge/getall",
            headers=self.headers
        )
        return response.json()
    
    def create_badge(self, badge_data: Dict) -> Dict:
        """Create a new badge"""
        response = requests.post(
            f"{self.base_url}/badge/create",
            json=badge_data,
            headers=self.headers
        )
        return response.json()
    
    def issue_badge(self, issue_data: Dict) -> Dict:
        """Issue a badge to a recipient"""
        response = requests.post(
            f"{self.base_url}/issue/create",
            json=issue_data,
            headers=self.headers
        )
        return response.json()

# Usage example
client = IssueBadgeClient(os.getenv("ISSUEBADGE_API_KEY"))
badges = client.get_all_badges()
```

## 🎨 Advanced Features

### **Custom Fields**
Create badges with custom fields for specific use cases:
```json
{
  "name": "Advanced Python Certification",
  "description": "Advanced Python programming certification",
  "custom_fields": [
    {
      "name": "Completion Date",
      "type": "date",
      "required": true
    },
    {
      "name": "Final Score",
      "type": "number",
      "required": true
    },
    {
      "name": "Instructor",
      "type": "text",
      "required": false
    }
  ]
}
```

### **Batch Operations**
Process multiple badges efficiently:
```javascript
// Batch create badges
const badges = [
  { name: "HTML Basics", description: "HTML fundamentals" },
  { name: "CSS Styling", description: "CSS styling techniques" },
  { name: "JavaScript Logic", description: "JavaScript programming" }
];

const results = await Promise.all(
  badges.map(badge => createBadge({
    ...badge,
    issuing_organization_name: "Code Academy",
    idempotency_key: `batch_${Date.now()}_${badge.name}`
  }))
);
```

### **Webhook Integration**
Set up webhooks to receive badge issuance notifications:
```javascript
// Express webhook handler
app.post('/webhook/badge-issued', (req, res) => {
  const { badge_id, recipient_email, issue_date } = req.body;
  
  // Process the badge issuance
  console.log(`Badge ${badge_id} issued to ${recipient_email} on ${issue_date}`);
  
  // Send to your analytics system
  analytics.track('badge_issued', {
    badge_id,
    recipient_email,
    issue_date
  });
  
  res.status(200).json({ received: true });
});
```

## 🔒 Security Best Practices

### **API Key Management**
- Store API keys in environment variables
- Use different keys for development/production
- Rotate keys regularly
- Never commit keys to version control

### **Request Validation**
```javascript
// Validate requests before sending
function validateBadgeData(data) {
  const required = ['name', 'description', 'issuing_organization_name'];
  const missing = required.filter(field => !data[field]);
  
  if (missing.length > 0) {
    throw new Error(`Missing required fields: ${missing.join(', ')}`);
  }
  
  return true;
}
```

### **Rate Limiting**
```javascript
// Implement rate limiting
const rateLimit = require('express-rate-limit');

const badgeAPILimiter = rateLimit({
  windowMs: 15 * 60 * 1000, // 15 minutes
  max: 100, // limit each IP to 100 requests per windowMs
  message: 'Too many badge API requests, please try again later'
});

app.use('/api/badges', badgeAPILimiter);
```

## 📊 Analytics & Monitoring

### **Track Badge Operations**
```javascript
// Analytics wrapper
class BadgeAnalytics {
  constructor(apiClient) {
    this.client = apiClient;
    this.analytics = new Analytics();
  }
  
  async createBadge(data) {
    const start = Date.now();
    try {
      const result = await this.client.createBadge(data);
      this.analytics.track('badge_created', {
        badge_name: data.name,
        duration: Date.now() - start,
        success: true
      });
      return result;
    } catch (error) {
      this.analytics.track('badge_creation_failed', {
        error: error.message,
        duration: Date.now() - start
      });
      throw error;
    }
  }
}
```

## 🚀 Deployment & Production

### **Environment Configuration**
```bash
# Production environment variables
ISSUEBADGE_API_KEY=prod_key_here
ISSUEBADGE_BASE_URL=https://api.issuebadge.com/v1
NODE_ENV=production
LOG_LEVEL=info
```

### **Docker Deployment**
```dockerfile
# Dockerfile for MCP server
FROM node:18-alpine

WORKDIR /app
COPY package*.json ./
RUN npm ci --only=production

COPY dist ./dist
COPY .env.production ./.env

EXPOSE 3000
CMD ["node", "dist/index.js"]
```

### **Health Checks**
```javascript
// Health check endpoint
app.get('/health', async (req, res) => {
  try {
    const keyValidation = await badgeClient.validateKey();
    res.json({
      status: 'healthy',
      timestamp: new Date().toISOString(),
      api_connection: keyValidation.success
    });
  } catch (error) {
    res.status(500).json({
      status: 'unhealthy',
      error: error.message
    });
  }
});
```

## 🆘 Troubleshooting

### **Common Issues**

#### **API Key Validation Failed**
```javascript
// Check API key format
if (!apiKey || !apiKey.startsWith('1|')) {
  console.error('Invalid API key format. Should start with "1|"');
}

// Test key validation
const validation = await validateKey(apiKey);
if (!validation.success) {
  console.error('Key validation failed:', validation.message);
}
```

#### **Badge Creation Errors**
```javascript
// Check required fields
const requiredFields = ['name', 'description', 'issuing_organization_name'];
const missing = requiredFields.filter(field => !badgeData[field]);

if (missing.length > 0) {
  console.error(`Missing required fields: ${missing.join(', ')}`);
}
```

#### **MCP Server Not Responding**
```bash
# Check MCP server logs
npm run build
DEBUG=true npm start

# Verify environment variables
echo $ISSUEBADGE_API_KEY
echo $ISSUEBADGE_BASE_URL
```

## 📞 Support & Community

### **Getting Help**
- **Documentation**: This guide and API docs
- **GitHub Issues**: Report bugs and request features
- **Email Support**: developers@issuebadge.com
- **Community Forum**: Join our developer community

### **Contributing**
We welcome contributions to improve the API and MCP server:
1. Fork the repository
2. Create a feature branch
3. Submit a pull request
4. Follow our coding standards

### **Resources**
- **API Status**: https://status.issuebadge.com
- **Changelog**: https://github.com/issuebadge/api/releases
- **Examples**: https://github.com/issuebadge/examples
- **MCP Registry**: https://github.com/modelcontextprotocol/servers

---

**Ready to start building with IssueBadge?** [Get your API key](https://dashboard.issuebadge.com/api-keys) and join thousands of developers creating amazing badge experiences!

*Last updated: December 2024*